%define url_ver	%(echo %{version}|sed 's/[.]/./g')

Name:		chessx
Version:	1.5.4
Release:	%mkrel 2
Summary:	An Open Source chess database
License:	GPLv2
Group:		Games/Boards
URL:		https://chessx.sourceforge.io/
Source0:	https://sourceforge.net/projects/chessx/files/%{name}/%{version}/%{name}-%{url_ver}.tgz

BuildRequires:	qttools5
BuildRequires:	pkgconfig(Qt5Concurrent)
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Multimedia)
BuildRequires:	pkgconfig(Qt5MultimediaWidgets)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5PrintSupport)
BuildRequires:	pkgconfig(Qt5Svg)
BuildRequires:	pkgconfig(Qt5TextToSpeech)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)
BuildRequires:	desktop-file-utils
BuildRequires:	imagemagick

%description
ChessX is an Open Source chess database. With ChessX you can operate on your
collection of chess games in many ways:
browse, edit, add, organize, analyze, etc.

%prep
%setup -q
%autopatch -p1

%build
%qmake_qt5 %{name}.pro

%{_qt5_bindir}/lrelease i18n/*.ts

%make_build

%install
# binary-repertory for games
mkdir -p %{buildroot}%{_gamesbindir}
install -m 0755 release/chessx %{buildroot}%{_gamesbindir}/%{name}

# data-repertory for games
mkdir -p %{buildroot}%{_gamesdatadir}/%{name}
cp -pr data/* %{buildroot}%{_gamesdatadir}/%{name}/
cp -pr i18n/*.qm %{buildroot}%{_gamesdatadir}/%{name}/lang/

# FIXME for correct assignment of rights of all circle_*.svg files
find %{buildroot} -name '*.svg' -exec chmod a-x  {} \;

# icons-repertory
for png in 128x128 64x64 32x32 22x22 16x16; do
  mkdir -p %{buildroot}%{_iconsdir}/hicolor/${png}/apps/
  convert -geometry $png data/images/%{name}.png %{buildroot}%{_iconsdir}/hicolor/${png}/apps/%{name}.png
done

# menu-entry
mkdir -p %{buildroot}%{_datadir}/applications
desktop-file-install \
	--dir=%{buildroot}%{_datadir}/applications/ \
	unix/%{name}.desktop

%files
%doc COPYING ChangeLog
%{_gamesbindir}/%{name}
%{_gamesdatadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png


%changelog
* Wed Dec 16 2020 umeabot <umeabot> 1.5.4-2.mga8
+ Revision: 1658220
- Rebuild for new Qt5

* Tue Jul 14 2020 daviddavid <daviddavid> 1.5.4-1.mga8
+ Revision: 1606017
- new version: 1.5.4
- update Url
- remove merged upstream patch
+ danf <danf>
- Switch URLs from http: to https:

* Sat Feb 15 2020 umeabot <umeabot> 1.4.6-5.mga8
+ Revision: 1524415
- Mageia 8 Mass Rebuild

* Sat Mar 30 2019 umeabot <umeabot> 1.4.6-4.mga7
+ Revision: 1381434
- Qt5 Rebuild

* Sat Sep 22 2018 umeabot <umeabot> 1.4.6-3.mga7
+ Revision: 1296118
- Mageia 7 Mass Rebuild

* Mon Jun 04 2018 daviddavid <daviddavid> 1.4.6-2.mga7
+ Revision: 1234415
- add patch to fix build with new Qt5 >= 5.11.0

* Sat Jul 01 2017 daviddavid <daviddavid> 1.4.6-1.mga6
+ Revision: 1108853
- new version: 1.4.6

* Tue Mar 22 2016 daviddavid <daviddavid> 1.4.0-1.mga6
+ Revision: 993896
- new version: 1.4.0
- remove merged upstream patches

* Fri Jan 22 2016 daviddavid <daviddavid> 1.3.2-3.mga6
+ Revision: 926541
- add patch1 to fix build with gcc 5.3.1
  * https://sourceforge.net/p/chessx/bugs/229/
- split out all Qt5 BuildRequires

* Mon Aug 10 2015 daviddavid <daviddavid> 1.3.2-2.mga6
+ Revision: 862351
- add patch0 to fix build with Qt 5.5
  * http://sourceforge.net/p/chessx/bugs/227/

* Sat Jun 20 2015 daviddavid <daviddavid> 1.3.2-1.mga6
+ Revision: 835883
- add missing BuildRequires on Qt5Multimedia
- new version: 1.3.2

* Sun Oct 19 2014 daviddavid <daviddavid> 1.2.2-1.mga5
+ Revision: 791779
- new version: 1.2.2
- switch to Qt5 build
- update BRs for Qt5 build

* Wed Oct 15 2014 umeabot <umeabot> 1.2.0-5.mga5
+ Revision: 739180
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2.0-4.mga5
+ Revision: 678374
- Mageia 5 Mass Rebuild

* Mon Aug 11 2014 daviddavid <daviddavid> 1.2.0-3.mga5
+ Revision: 661801
- bump release

* Mon Aug 11 2014 daviddavid <daviddavid> 1.2.0-2.mga5
+ Revision: 661794
- fix an issue with the compilation of available languages
  * we need to compile all languages files before %%make

* Mon Aug 04 2014 daviddavid <daviddavid> 1.2.0-1.mga5
+ Revision: 659689
- update url_version of Source0 (now uses '.' rather than '-')
- remove the previous fix of desktop file as it is now fixed upstream
- fix for correct assignment of rights of all the circle_*.svg files
- new version: 1.2.0

* Tue Mar 18 2014 david-david <david-david> 1.1.0-1.mga5
+ Revision: 605146
- fix upstream desktop file on missing semicolon (';')
- update linkurl Source0
- add more icons
- use desktop file provides on tarball
- new version: 1.1.0

* Fri Feb 14 2014 dams <dams> 1.0.0-1.mga5
+ Revision: 591447
- new version 1.0.0

* Fri Oct 18 2013 umeabot <umeabot> 0.9.4-4.mga4
+ Revision: 503319
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 0.9.4-3.mga3
+ Revision: 347673
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 dams <dams> 0.9.4-2.mga3
+ Revision: 332984
- add back icon (broken by last update)

* Mon Dec 17 2012 kamil <kamil> 0.9.4-1.mga3
+ Revision: 332147
- new version 0.9.4

* Sat Dec 01 2012 kamil <kamil> 0.9.2-2.mga3
+ Revision: 324365
- clean a bit .spec

* Fri Nov 16 2012 dams <dams> 0.9.2-1.mga3
+ Revision: 318925
- new version 0.9.2
- update buildrequire
- now use project icon instead of generic icon
- update specfile to enable i18n translations

* Mon Sep 19 2011 obgr_seneca <obgr_seneca> 0.8-1.mga2
+ Revision: 145389
- imported package chessx


* Sun Sep 18 2011 Kamil Rytarowski <n54@gmx.com> 0.8-1
- initial package for Mageia
- thanks to some guys at pacman for the inspiration taken from their spec file
